@@ -45,6 +45,7 @@
 #include <tools/profile.h>
 #include <tools/settings.h>
 #include <tools/version.h>
+#include <tools/qttools.h>
 
 #include <QtCore/qbytearraylist.h>
 #include <QtCore/qcoreapplication.h>
@@ -68,12 +69,6 @@ static QStringList expectedArchs()
             QStringLiteral("x86"), QStringLiteral("x86_64")};
 }
 
-
-static QString subProfileName(const QString &mainProfileName, const QString &arch)
-{
-    return mainProfileName + QLatin1Char('-') + arch;
-}
-
 void setupSdk(qbs::Settings *settings, const QString &profileName, const QString &sdkDirPath)
 {
     if (!QDir(sdkDirPath).exists()) {
@@ -100,10 +95,10 @@ static QString mapArch(const QString &androidName)
 }
 
 struct QtAndroidInfo {
-    bool isValid() const { return !arch.isEmpty(); }
+    bool isValid() const { return !archs.isEmpty(); }
 
     QString qmakePath;
-    QString arch;
+    QStringList archs;
     QString platform;
 };
 
@@ -117,19 +112,31 @@ static QtAndroidInfo getInfoForQtDir(const QString &qtDir)
     if (!qdevicepri.open(QIODevice::ReadOnly))
         return info;
     while (!qdevicepri.atEnd()) {
+        // For Qt < 5.14 use DEFAULT_ANDROID_TARGET_ARCH (which is the abi) to compute
+        // the architecture
+        // DEFAULT_ANDROID_ABIS doesn't exit
+        // For Qt >= 5.14:
+        // DEFAULT_ANDROID_TARGET_ARCH doesn't exist, use DEFAULT_ANDROID_ABIS to compute
+        // the architectures
         const QByteArray line = qdevicepri.readLine().simplified();
         const bool isArchLine = line.startsWith("DEFAULT_ANDROID_TARGET_ARCH");
+        const bool isAbisLine = line.startsWith("DEFAULT_ANDROID_ABIS");
         const bool isPlatformLine = line.startsWith("DEFAULT_ANDROID_PLATFORM");
-        if (!isArchLine && !isPlatformLine)
+        if (!isArchLine && !isPlatformLine && !isAbisLine)
             continue;
         const QList<QByteArray> elems = line.split('=');
         if (elems.size() != 2)
             continue;
         const QString rhs = QString::fromLatin1(elems.at(1).trimmed());
-        if (isArchLine)
-            info.arch = mapArch(rhs);
-        else
+        if (isArchLine) {
+            info.archs << mapArch(rhs);
+        } else if (isAbisLine) {
+            const auto abis = rhs.split(QLatin1Char(' '));
+            for (const QString &abi: abis)
+                info.archs << mapArch(abi);
+        } else {
             info.platform = rhs;
+        }
     }
     return info;
 }
@@ -142,13 +149,16 @@ static QtInfoPerArch getQtAndroidInfo(const QString &qtSdkDir)
         return archs;
 
     QStringList qtDirs(qtSdkDir);
-    QDirIterator dit(qtSdkDir, QStringList() << QStringLiteral("android_*"), QDir::Dirs);
+    const QStringList nameFilters{QStringLiteral("android_*"), QStringLiteral("android")};
+    QDirIterator dit(qtSdkDir, nameFilters, QDir::Dirs);
     while (dit.hasNext())
         qtDirs << dit.next();
-    for (auto it = qtDirs.cbegin(); it != qtDirs.cend(); ++it) {
-        const QtAndroidInfo info = getInfoForQtDir(*it);
-        if (info.isValid())
-            archs.insert(info.arch, info);
+    for (const auto &qtDir : std::as_const(qtDirs)) {
+        const QtAndroidInfo info = getInfoForQtDir(qtDir);
+        if (info.isValid()) {
+            for (const QString &arch: info.archs)
+                archs.insert(arch, info);
+        }
     }
     return archs;
 }
@@ -227,29 +237,13 @@ static void setupNdk(qbs::Settings *settings, const QString &profileName, const
         const QtAndroidInfo qtAndroidInfo = infoPerArch.value(arch);
         if (!qtAndroidInfo.isValid())
             continue;
-        const QString subProName = subProfileName(profileName, arch);
-        const QString setupQtPath = qApp->applicationDirPath() + qls("/qbs-setup-qt");
-        QProcess setupQt;
-        setupQt.start(setupQtPath, QStringList({ qtAndroidInfo.qmakePath, subProName }));
-        if (!setupQt.waitForStarted()) {
-            throw ErrorInfo(Tr::tr("Setting up Qt profile failed: '%1' "
-                                   "could not be started.").arg(setupQtPath));
-        }
-        if (!setupQt.waitForFinished()) {
-            throw ErrorInfo(Tr::tr("Setting up Qt profile failed: Error running '%1' (%2)")
-                            .arg(setupQtPath, setupQt.errorString()));
-        }
-        if (setupQt.exitCode() != 0) {
-            throw ErrorInfo(Tr::tr("Setting up Qt profile failed: '%1' returned with "
-                                   "exit code %2.").arg(setupQtPath).arg(setupQt.exitCode()));
-        }
-        settings->sync();
-        qbs::Internal::TemporaryProfile p(subProName, settings);
-        qmakeFilePaths << p.p.value(qls("moduleProviders.Qt.qmakeFilePaths")).toStringList();
+        qmakeFilePaths << qtAndroidInfo.qmakePath;
         platform = maximumPlatform(platform, qtAndroidInfo.platform);
     }
-    if (!qmakeFilePaths.empty())
+    if (!qmakeFilePaths.empty()) {
+        qmakeFilePaths.removeDuplicates();
         mainProfile.setValue(qls("moduleProviders.Qt.qmakeFilePaths"), qmakeFilePaths);
+    }
     if (!platform.isEmpty())
         mainProfile.setValue(qls("Android.ndk.platform"), platform);
 }
